@@ -1,6 +1,13 @@
+from __future__ import print_function
 import argparse
-from get_by_city import get_by_city_args, city_parse 
-from get_by_postalcode import get_by_postalcode_args, postalcode_parse
+
+# handle ModuleNotFoundError python3 execution
+try:
+    from cli_weather.get_by_city import get_by_city_args, city_parse 
+    from cli_weather.get_by_postalcode import get_by_postalcode_args, postalcode_parse
+except ModuleNotFoundError:
+    from get_by_city import get_by_city_args, city_parse 
+    from get_by_postalcode import get_by_postalcode_args, postalcode_parse
 
 def main():
     parser = argparse.ArgumentParser('cli-weather')
@@ -18,4 +25,5 @@ def main():
         postalcode_parse(args)
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
+    
\ No newline at end of file
